@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9965 2017-05-13 03:21:53Z David $
+# $Id: __init__.py 9991 2017-05-28 11:00:12Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-05-13 11:21:53 +0800 (Sat, 13 May 2017) $
-# $Revision: 9965 $
+# $Date: 2017-05-28 19:00:12 +0800 (Sun, 28 May 2017) $
+# $Revision: 9991 $
 
 import os
 import sys
@@ -301,13 +301,18 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         ]
     else:
         ALLOWED_HOSTS = ['127.0.0.1', 'localhost']
-        
+    
+    defaultAllowedDomains = {
+        ALLOWED_DOMAINS: ['127.0.0.1', 'localhost']
+    }
+
     if settingsDict.get('ALLOWED_DOMAINS', None):
         ALLOWED_HOSTS += settingsDict['ALLOWED_DOMAINS']
     else:
         if settingsDict['SERVER_MODE'] != DEVELOPMENT:
             if warns:
-                require('ALLOWED_DOMAINS', settingsDict)
+                warnWithout(
+                    'ALLOWED_DOMAINS', settingsDict, defaultAllowedDomains)
 
     adminDefaults = {
         'ADMINS': ADMINS,
